=============================
README for HydraTK GUI client
=============================

| GUI client for HydraTK
| Features:

* Project explorer
* Editor for Python and Jedi files - syntax highlighting, text formatting, code autocomplete
* Jedi test files design
* Multi-language support
* Plugins: SyntaxChecker, GitClient

OS and Python versions support
==============================

| Currently the Windows and Linux platform with CPython 2.6, 2.7, 3.3, 3.4, 3.5, 3.6, PyPy 2.7 is supported.